jaclearn.imageaug.photography
=============================

.. automodule:: jaclearn.imageaug.photography

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      brightness_augment
      color_augment_pack
      contrast_augment
      grayscale_augment
      lighting_augment
      saturation_augment
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: brightness_augment

.. autofunction:: color_augment_pack

.. autofunction:: contrast_augment

.. autofunction:: grayscale_augment

.. autofunction:: lighting_augment

.. autofunction:: saturation_augment


